@@ -4,8 +4,8 @@ from typing import Any, Callable, Union
 from fastapi import FastAPI
 from typer import Typer
 
-from fastack.controller import Controller
-
+from .controller import Controller
+from .middleware import MergeAppStateMiddleware
 from .utils import import_attr
 
 
@@ -34,13 +34,26 @@ class Fastack(FastAPI):
                 self.cli.command(command.__name__)(command)
 
     def include_controller(self, controller: Controller, **kwds):
+        assert isinstance(
+            controller, Controller
+        ), f"Controller must be an instance of {controller!r}"
         router = controller.build(**kwds)
         self.include_router(router)
 
 
 def create_app(settings: ModuleType, **kwds):
+    kwds.setdefault("title", "Fastack")
+    kwds.setdefault("description", "Fastack Framework")
+    kwds.setdefault(
+        "contact",
+        {
+            "name": "Fastack",
+            "url": "https://github.com/aprilahijriyan/fastack",
+        },
+    )
     kwds["debug"] = settings.DEBUG
     app = Fastack(**kwds)
+    app.add_middleware(MergeAppStateMiddleware)
     app.set_settings(settings)
     app.load_plugins()
     app.load_commands()
