@@ -11,7 +11,6 @@ from .pagination import PageNumberPagination, Pagination
 
 
 class Controller:
-    queryset: Any = None
     url_prefix: str = None
     mapping_endpoints = MAPPING_ENDPOINTS
     method_endpoints = METHOD_ENDPOINTS
@@ -164,7 +163,7 @@ class CreateController(Controller):
 
 
 class UpdateController(Controller):
-    def update(self, id: int) -> Response:
+    def update(self, id: int, body: BaseModel) -> Response:
         raise NotImplementedError
 
 
