@@ -16,6 +16,9 @@ class Model(Document):
 
     def update(self, **kwargs):
         kwargs["date_updated"] = datetime.utcnow()
+        for k, v in kwargs.items():
+            setattr(self, k, v)
+
         return super().update(**kwargs)
 
     def save(
@@ -47,6 +50,7 @@ class Model(Document):
 
     def serialize(self) -> dict:
         return {
+            "id": str(self.pk),
             "date_created": self.date_created,
             "date_updated": self.date_updated,
         }
